@@ -28,6 +28,7 @@
 #include "serialized_object.h"
 
 #include <memory>
+#include "wx_xml_compatibility.h"
 
 namespace
 {
@@ -121,6 +122,7 @@ void TabInfo::DeSerialize(Archive &arch)
 	arch.Read(wxT("FirstVisibleLine"), m_firstVisibleLine);
 	arch.Read(wxT("CurrentLine"), m_currentLine);
 	arch.Read(wxT("Bookmarks"), m_bookmarks);
+	arch.Read(wxT("CollapsedFolds"), m_folds);
 }
 
 void TabInfo::Serialize(Archive &arch)
@@ -129,6 +131,7 @@ void TabInfo::Serialize(Archive &arch)
 	arch.Write(wxT("FirstVisibleLine"), m_firstVisibleLine);
 	arch.Write(wxT("CurrentLine"), m_currentLine);
 	arch.Write(wxT("Bookmarks"), m_bookmarks);
+	arch.Write(wxT("CollapsedFolds"), m_folds);
 }
 
 // class Archive
@@ -209,6 +212,24 @@ bool Archive::Write(const wxString &name, std::vector<TabInfo>& _vTabInfoArr)
 	return true;
 }
 
+bool Archive::Write(const wxString &name, std::vector<int>& _vInt)
+{
+	if (!m_root) {
+		return false;
+	}
+	wxXmlNode *node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("IntVector"));
+	m_root->AddChild(node);
+	node->AddProperty(wxT("Name"), name);
+
+	//add an entry for each int in the vector
+	for (size_t i=0; i<_vInt.size(); ++i) {
+		wxXmlNode *child = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("IntVectorItem"));
+		node->AddChild(child);
+		child->AddProperty(wxT("Value"), wxString::Format(wxT("%i"), _vInt.at(i)));
+	}
+	return true;
+}
+
 bool Archive::Write(const wxString &name, const StringMap &str_map)
 {
 	if (!m_root) {
@@ -318,6 +339,32 @@ bool Archive::Read(const wxString &name, std::vector<TabInfo>& _vTabInfoArr)
 	return false;
 }
 
+bool Archive::Read(const wxString &name, std::vector<int>& _vInt)
+{
+	if (!m_root) {
+		return false;
+	}
+
+	wxXmlNode *node = FindNodeByName(m_root, wxT("IntVector"), name);
+	if (node) {
+		//fill the output array with the values
+		_vInt.clear();
+		wxXmlNode *child = node->GetChildren();
+		while (child) {
+			if (child->GetName() == wxT("IntVectorItem")) {
+				long value;
+                wxString stringvalue = child->GetPropVal(wxT("Value"), wxEmptyString);
+                if (stringvalue.ToLong(&value)) {
+                    _vInt.push_back(value);
+                }
+			}
+			child = child->GetNext();
+		}
+		return true;
+	}
+	return false;
+}
+
 bool Archive::Read(const wxString &name, StringMap &str_map)
 {
 	if (!m_root) {
@@ -491,7 +538,9 @@ bool Archive::Read(const wxString &name, size_t &value)
 {
 	long v = 0;
 	bool res = Read(name, v);
-	value = v;
+	if(res) {
+		value = v;
+	}
 	return res;
 }
 
@@ -499,7 +548,9 @@ bool Archive::Read(const wxString &name, wxFileName &fileName)
 {
 	wxString value;
 	bool res = Read(name, value);
-	fileName = wxFileName(value);
+	if(res) {
+		fileName = wxFileName(value);
+	}
 	return res;
 }
 
@@ -626,3 +677,47 @@ bool Archive::Read(const wxString& name, std::map<wxString, wxString>& strinMap)
 	}
 	return false;
 }
+
+bool Archive::Read(const wxString& name, std::set<wxString>& s)
+{
+	if (!m_root) {
+		return false;
+	}
+
+	wxXmlNode *node = FindNodeByName(m_root, wxT("std_string_set"), name);
+	if (node) {
+		//fill the output array with the values
+		s.clear();
+		wxXmlNode *child = node->GetChildren();
+		while (child) {
+			if (child->GetName() == wxT("SetEntry")) {
+				wxString value;
+				value = child->GetNodeContent();
+				s.insert(value);
+			}
+			child = child->GetNext();
+		}
+		return true;
+	}
+	return false;
+}
+
+bool Archive::Write(const wxString& name, const std::set<wxString>& s)
+{
+	if (!m_root) {
+		return false;
+	}
+
+	wxXmlNode *node = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("std_string_set"));
+	m_root->AddChild(node);
+	node->AddProperty(wxT("Name"), name);
+
+	//add an entry for each wxString in the array
+	std::set<wxString>::const_iterator iter = s.begin();
+	for ( ; iter != s.end(); iter++ ) {
+		wxXmlNode *child = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, wxT("SetEntry"));
+		node->AddChild(child);
+		SetNodeContent(child, *iter);
+	}
+	return true;
+}
