@@ -6,7 +6,20 @@
 #include "variable.h"
 #include <stdio.h>
 
-class clFunction
+#ifndef WXDLLIMPEXP_CL
+
+#ifdef WXMAKINGDLL_CL
+#    define WXDLLIMPEXP_CL __declspec(dllexport)
+#elif defined(WXUSINGDLL_CL)
+#    define WXDLLIMPEXP_CL __declspec(dllimport)
+#else // not making nor using DLL
+#    define WXDLLIMPEXP_CL
+#endif
+
+#endif
+
+
+class WXDLLIMPEXP_CL clFunction
 {
 public:
 	std::string     m_name;
@@ -18,7 +31,8 @@ public:
 	bool            m_isVirtual;
 	bool            m_isPureVirtual;
 	bool            m_isConst;
-
+	std::string     m_throws;
+	
 public:
 	clFunction();
 	virtual ~clFunction();
