@@ -24,11 +24,12 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "environmentconfig.h"
-#include "imacromanager.h"
 #include <wx/aui/framemanager.h>
+#include "macromanager.h"
 #include "async_executable_cmd.h"
 #include <wx/bitmap.h>
 #include "dirsaver.h"
+#include "cl_aui_tb_are.h"
 #include <wx/app.h>
 #include "workspace.h"
 #include "globals.h"
@@ -62,7 +63,7 @@ extern "C" EXPORT PluginInfo GetPluginInfo()
 	PluginInfo info;
 	info.SetAuthor(wxT("Eran Ifrah"));
 	info.SetName(wxT("ExternalTools"));
-	info.SetDescription(wxT("A plugin that allows user to launch external tools from within CodeLite"));
+	info.SetDescription(_("A plugin that allows user to launch external tools from within CodeLite"));
 	info.SetVersion(wxT("v1.0"));
 	return info;
 }
@@ -78,7 +79,7 @@ ExternalToolsPlugin::ExternalToolsPlugin(IManager *manager)
 		, m_pipedProcess(NULL)
 		, m_parentMenu  (NULL)
 {
-	m_longName = wxT("A plugin that allows user to launch external tools from within CodeLite");
+	m_longName = _("A plugin that allows user to launch external tools from within CodeLite");
 	m_shortName = wxT("ExternalTools");
 	topWin = m_mgr->GetTheApp();
 
@@ -121,14 +122,16 @@ clToolBar *ExternalToolsPlugin::CreateToolBar(wxWindow *parent)
 		m_mgr->GetConfigTool()->ReadObject(wxT("ExternalTools"), &inData);
 
 		if (size == 24) {
-			m_tb->AddTool(XRCID("external_tools_settings"), wxT("Configure external tools..."), wxXmlResource::Get()->LoadBitmap(wxT("configure_ext_tools24")), wxT("Configure external tools..."));
-			m_tb->AddTool(XRCID("stop_external_tool"), wxT("Stop external tool"), wxXmlResource::Get()->LoadBitmap(wxT("stop_external_tool24")), wxT("Stop external tool"));
+			m_tb->AddTool(XRCID("external_tools_settings"), _("Configure external tools..."), m_mgr->GetStdIcons()->LoadBitmap(wxT("toolbars/24/external-tools/configure")), _("Configure external tools..."));
+			m_tb->AddTool(XRCID("stop_external_tool"),      _("Stop external tool"),          m_mgr->GetStdIcons()->LoadBitmap(wxT("toolbars/24/build/stop")),               _("Stop external tool"));
 		} else {
-			m_tb->AddTool(XRCID("external_tools_settings"), wxT("Configure external tools..."), wxXmlResource::Get()->LoadBitmap(wxT("configure_ext_tools16")), wxT("Configure external tools..."));
-			m_tb->AddTool(XRCID("stop_external_tool"), wxT("Stop external tool"), wxXmlResource::Get()->LoadBitmap(wxT("stop_external_tool16")), wxT("Stop external tool"));
+			m_tb->AddTool(XRCID("external_tools_settings"), _("Configure external tools..."), m_mgr->GetStdIcons()->LoadBitmap(wxT("toolbars/16/external-tools/configure") ), _("Configure external tools..."));
+			m_tb->AddTool(XRCID("stop_external_tool"),      _("Stop external tool"),          m_mgr->GetStdIcons()->LoadBitmap(wxT("toolbars/16/build/stop")),                _("Stop external tool"));
 		}
 		m_tb->AddSeparator();
-
+#if USE_AUI_TOOLBAR
+		m_tb->SetArtProvider(new CLMainAuiTBArt());
+#endif
 		std::vector<ToolInfo> tools = inData.GetTools();
 		std::sort(tools.begin(), tools.end(), DecSort());
 
@@ -139,21 +142,21 @@ clToolBar *ExternalToolsPlugin::CreateToolBar(wxWindow *parent)
 			wxFileName icon16(ti.GetIcon16());
 
 			if (size == 24) {
-				wxBitmap bmp(wxXmlResource::Get()->LoadBitmap(wxT("ext_tool_default24")));
+				wxBitmap bmp( m_mgr->GetStdIcons()->LoadBitmap(wxT("toolbars/24/external-tools/cog") ));
 				if (icon24.FileExists()) {
 					bmp.LoadFile(icon24.GetFullPath(), wxBITMAP_TYPE_PNG);
 					if (bmp.IsOk() == false) {
-						bmp = wxXmlResource::Get()->LoadBitmap(wxT("ext_tool_default24"));
+						bmp = m_mgr->GetStdIcons()->LoadBitmap(wxT("toolbars/24/external-tools/cog") );
 					}
 				}
 				m_tb->AddTool(wxXmlResource::GetXRCID(ti.GetId().c_str()), ti.GetName(), bmp, ti.GetName());
 
 			} else if (size == 16) {
-				wxBitmap bmp(wxXmlResource::Get()->LoadBitmap(wxT("ext_tool_default16")));
+				wxBitmap bmp(m_mgr->GetStdIcons()->LoadBitmap(wxT("toolbars/16/external-tools/cog") ));
 				if (icon16.FileExists()) {
 					bmp.LoadFile(icon16.GetFullPath(), wxBITMAP_TYPE_PNG);
 					if (bmp.IsOk() == false) {
-						bmp = wxXmlResource::Get()->LoadBitmap(wxT("ext_tool_default16"));
+						bmp = m_mgr->GetStdIcons()->LoadBitmap(wxT("toolbars/16/external-tools/cog") );
 					}
 				}
 
@@ -179,12 +182,6 @@ void ExternalToolsPlugin::HookPopupMenu(wxMenu *menu, MenuType type)
 	wxUnusedVar(type);
 }
 
-void ExternalToolsPlugin::UnHookPopupMenu(wxMenu *menu, MenuType type)
-{
-	wxUnusedVar(menu);
-	wxUnusedVar(type);
-}
-
 void ExternalToolsPlugin::UnPlug()
 {
 }
@@ -235,8 +232,8 @@ void ExternalToolsPlugin::DoLaunchTool(const ToolInfo& ti)
 	working_dir = ti.GetWd();
 
 	if (m_mgr->IsWorkspaceOpen()) {
-		command     = m_mgr->GetMacrosManager()->Expand(command, m_mgr, m_mgr->GetWorkspace()->GetActiveProjectName());
-		working_dir = m_mgr->GetMacrosManager()->Expand(working_dir, m_mgr, m_mgr->GetWorkspace()->GetActiveProjectName());
+		command     = MacroManager::Instance()->Expand(command, m_mgr, m_mgr->GetWorkspace()->GetActiveProjectName());
+		working_dir = MacroManager::Instance()->Expand(working_dir, m_mgr, m_mgr->GetWorkspace()->GetActiveProjectName());
 	}
 
 	// check to see if we require to save all files before continuing
@@ -336,7 +333,7 @@ void ExternalToolsPlugin::DoCreatePluginMenu()
 
 		wxMenu *menu = new wxMenu();
 		wxMenuItem *item(NULL);
-		item = new wxMenuItem(menu, XRCID("external_tools_settings"), wxT("Configure external tools..."), wxEmptyString, wxITEM_NORMAL);
+		item = new wxMenuItem(menu, XRCID("external_tools_settings"), _("Configure external tools..."), wxEmptyString, wxITEM_NORMAL);
 		menu->Append(item);
 		menu->AppendSeparator();
 
@@ -350,7 +347,7 @@ void ExternalToolsPlugin::DoCreatePluginMenu()
 			menu->Append(item);
 		}
 
-		m_parentMenu->Append(MENU_ID, wxT("External Tools"), menu);
+		m_parentMenu->Append(MENU_ID, _("External Tools"), menu);
 		topWin->Connect(XRCID("external_tools_settings"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(ExternalToolsPlugin::OnSettings), NULL, (wxEvtHandler*)this);
 	}
 }
