@@ -22,7 +22,7 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
- #ifndef GIZMOS_H
+#ifndef GIZMOS_H
 #define GIZMOS_H
 
 #include "plugin.h"
@@ -30,11 +30,11 @@
 #include "newclassdlg.h"
 #include "newwxprojectinfo.h"
 
-class GizmosPlugin : public IPlugin
+class WizardsPlugin : public IPlugin
 {
 	void CreateClass(const NewClassInfo &info);
 	wxString DoGetVirtualFuncImpl(const NewClassInfo &info);
-	wxString DoGetVirtualFuncDecl(const NewClassInfo &info);
+	wxString DoGetVirtualFuncDecl(const NewClassInfo &info, const wxString& separator);
 	std::vector<wxMenuItem*> m_vdDynItems;
 protected:
 	void CreateWxProject(NewWxProjectInfo &info);
@@ -42,8 +42,8 @@ protected:
 	void DoPopupButtonMenu(wxPoint pt);
 
 public:
-	GizmosPlugin(IManager *manager);
-	~GizmosPlugin();
+	WizardsPlugin(IManager *manager);
+	~WizardsPlugin();
 
 	//--------------------------------------------
 	//Abstract methods
@@ -51,7 +51,6 @@ public:
 	virtual clToolBar *CreateToolBar(wxWindow *parent);
 	virtual void CreatePluginMenu(wxMenu *pluginsMenu);
 	virtual void HookPopupMenu(wxMenu *menu, MenuType type);
-	virtual void UnHookPopupMenu(wxMenu *menu, MenuType type);
 	virtual void UnPlug();
 
 	void DoCreateNewPlugin   ();
