@@ -25,6 +25,7 @@
  #include "wx/xrc/xmlres.h"
 #include "windowattrmanager.h"
 #include "imanager.h"
+#include "globals.h"
 #include "newwxprojectdlg.h"
 #include "wx/msgdlg.h"
 #include "workspace.h"
@@ -34,15 +35,21 @@ NewWxProjectDlg::NewWxProjectDlg( wxWindow* parent, IManager *mgr  )
 , m_mgr(mgr)
 {
 	m_bitmap1->SetBitmap(wxXmlResource::Get()->LoadBitmap(wxT("wx_project_header")));
-	m_choiceApplicationType->SetSelection(wxProjectTypeGUI);
+	m_choiceApplicationType->SetSelection(wxProjectTypeSimpleMain);
 	m_dirPicker->SetPath(m_mgr->GetWorkspace()->GetWorkspaceFileName().GetPath(wxPATH_GET_VOLUME|wxPATH_GET_SEPARATOR));
+	const wxString VersionChoices[] = { wxTRANSLATE("Default"), wxT("2.6"), wxT("2.8"), wxT("2.9"), wxT("3.0") };
+	m_stringManager.AddStrings(sizeof(VersionChoices)/sizeof(wxString), VersionChoices, wxT("Default"), m_choiceVersion);
+	
 	m_textCtrlName->SetFocus();
 
 #if defined (__WXMSW__)	
 	m_checkBoxMWindows->SetValue(true);
+	m_checkBoxWinRes->SetValue(true);
 #else
 	m_checkBoxMWindows->SetValue(false);
 	m_checkBoxMWindows->Enable(false);
+	m_checkBoxWinRes->SetValue(false);
+	m_checkBoxWinRes->Enable(false);
 #endif
 	WindowAttrManager::Load(this, wxT("NewWxProjectDlgAttr"), m_mgr->GetConfigTool());
 }
@@ -69,17 +76,17 @@ bool NewWxProjectDlg::ValidateInput()
 {
 	if(m_textCtrlName->GetValue().IsEmpty()){
 		wxString msg;
-		msg << wxT("Invalid project name '") << m_textCtrlName->GetValue() << wxT("'\n");
-		msg << wxT("Valid characters for project name are [0-9A-Za-z_]");
-		wxMessageBox(msg, wxT("CodeLite"), wxICON_WARNING|wxOK);
+		msg << _("Invalid project name '") << m_textCtrlName->GetValue() << wxT("'\n");
+		msg << _("Valid characters for project name are [0-9A-Za-z_]");
+		wxMessageBox(msg, _("CodeLite"), wxICON_WARNING|wxOK);
 		return false;
 	}
 	
 	if(m_textCtrlName->GetValue().find_first_not_of(wxT("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_")) != wxString::npos){
 		wxString msg;
-		msg << wxT("Invalid project name '") << m_textCtrlName->GetValue() << wxT("'\n");
-		msg << wxT("Valid characters for project name are [0-9A-Za-z_]");
-		wxMessageBox(msg, wxT("CodeLite"), wxICON_WARNING|wxOK);
+		msg << _("Invalid project name '") << m_textCtrlName->GetValue() << wxT("'\n");
+		msg << _("Valid characters for project name are [0-9A-Za-z_]");
+		wxMessageBox(msg, _("CodeLite"), wxICON_WARNING|wxOK);
 		return false;
 	}
 
@@ -92,7 +99,7 @@ bool NewWxProjectDlg::ValidateInput()
 	
 	wxFileName::Mkdir(path, 0777, wxPATH_MKDIR_FULL);
 	if ( !wxDirExists(path) ) {
-		wxMessageBox(wxString::Format(wxT("Failed to create the path: %s\nA permissions problem, perhaps?"), path.c_str() ), wxT("Error"), wxOK | wxICON_HAND);
+		wxMessageBox(wxString::Format(_("Failed to create the path: %s\nA permissions problem, perhaps?"), path.c_str() ), _("Error"), wxOK | wxICON_HAND);
 		return false;
 	}
 
@@ -107,11 +114,27 @@ void NewWxProjectDlg::GetProjectInfo(NewWxProjectInfo &info)
 	if(m_checkBoxMWindows->IsChecked()){
 		flag |= wxWidgetsSetMWindows;
 	}
+	
+	if(m_checkBoxWinRes->IsChecked()){
+		flag |= wxWidgetsWinRes;
+	}
 
 	if(m_checkBoxUnicode->IsChecked()){
 		flag |= wxWidgetsUnicode;
 	}
 	
+	if(m_checkBoxStatic->IsChecked()){
+		flag |= wxWidgetsStatic;
+	}
+	
+	if(m_checkBoxUniversal->IsChecked()){
+		flag |= wxWidgetsUniversal;
+	}
+	
+	if(m_checkBoxPCH->IsChecked()){
+		flag |= wxWidgetsPCH;
+	}
+	
 	if(m_checkBoxCreateSeparateDir->IsChecked()) {
 		path << wxFileName::GetPathSeparator();
 		path << m_textCtrlName->GetValue();
@@ -121,12 +144,14 @@ void NewWxProjectDlg::GetProjectInfo(NewWxProjectInfo &info)
 	info.SetType(m_choiceApplicationType->GetSelection());
 	info.SetName(m_textCtrlName->GetValue());
 	info.SetPath(path);
+	info.SetPrefix(m_textCtrlPrefix->GetValue());
+	info.SetVersion(m_stringManager.GetStringSelection());
 }
 
 void NewWxProjectDlg::OnChoiceChanged(wxCommandEvent &e)
 {
 #ifdef __WXMSW__
-	if(e.GetSelection() == 1) {	//Simple main with wxWidgets enabled
+	if(e.GetSelection() == wxProjectTypeSimpleMain) {
 		m_checkBoxMWindows->SetValue(false);
 		m_checkBoxMWindows->Enable(false);
 	} else {
