@@ -1,3 +1,28 @@
+//////////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+//
+// copyright            : (C) 2014 The CodeLite Team
+// file name            : addoptioncheckdlg.cpp
+//
+// -------------------------------------------------------------------------
+// A
+//              _____           _      _     _ _
+//             /  __ \         | |    | |   (_) |
+//             | /  \/ ___   __| | ___| |    _| |_ ___
+//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
+//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
+//              \____/\___/ \__,_|\___\_____/_|\__\___|
+//
+//                                                  F i l e
+//
+//    This program is free software; you can redistribute it and/or modify
+//    it under the terms of the GNU General Public License as published by
+//    the Free Software Foundation; either version 2 of the License, or
+//    (at your option) any later version.
+//
+//////////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+
 #include "addoptioncheckdlg.h"
 #include "windowattrmanager.h"
 #include <wx/tokenzr.h>
@@ -127,7 +152,7 @@ void AddOptionCheckDlg::UpdateCmdLine()
 	std::list<wxString>::const_iterator itOption = options.begin();
 	for ( ; itOption != options.end(); ++itOption)
 	{
-		if(!value.Contains(*itOption))
+		if(!value.Contains(*itOption + wxT(";")))
 		{
 			if(!value.empty()) value << wxT(";");
 			value << *itOption;
