@@ -43,8 +43,8 @@ struct NameSorter {
 };
 
 AttachDbgProcDlg::AttachDbgProcDlg( wxWindow* parent )
-		: AttachDbgProcBaseDlg( parent )
-		, m_selectedItem(wxNOT_FOUND)
+	: AttachDbgProcBaseDlg( parent )
+	, m_selectedItem(wxNOT_FOUND)
 {
 	wxArrayString choices = DebuggerMgr::Get().GetAvailableDebuggers();
 	m_choiceDebugger->Append(choices);
@@ -53,49 +53,61 @@ AttachDbgProcDlg::AttachDbgProcDlg( wxWindow* parent )
 		m_choiceDebugger->SetSelection(0);
 	}
 
-	m_listCtrlProcesses->InsertColumn(0, wxT("PID"));
-	m_listCtrlProcesses->InsertColumn(1, wxT("Name"));
+	m_listCtrlProcesses->InsertColumn(0, _("PID"));
+	m_listCtrlProcesses->InsertColumn(1, _("Name"));
 
-	RefreshProcessesList();
-	m_listCtrlProcesses->SetFocus();
+	RefreshProcessesList(wxEmptyString);
+	m_textCtrlFilter->SetFocus();
 	Centre();
 
 	WindowAttrManager::Load(this, wxT("AttachDbgProcDlg"), NULL);
 }
 
-void AttachDbgProcDlg::RefreshProcessesList(int colToSort)
+void AttachDbgProcDlg::RefreshProcessesList(wxString filter, int colToSort)
 {
 	m_listCtrlProcesses->Freeze();
 	m_listCtrlProcesses->DeleteAllItems();
 
+	filter.Trim().Trim(false);
+
 	//Populate the list with list of processes
 	std::vector<ProcessEntry> proclist;
 	ProcUtils::GetProcessList(proclist);
 
 	if (colToSort == 0) {//sort by PID
 		std::sort(proclist.begin(), proclist.end(), PIDSorter());
-		
+
 	} else if (colToSort == 1) {//sort by name
 		std::sort(proclist.begin(), proclist.end(), NameSorter());
-		
+
 	}
 
+	filter.MakeLower();
 	for (size_t i=0; i<proclist.size(); i++) {
-		long item = AppendListCtrlRow(m_listCtrlProcesses);
-		ProcessEntry entry = proclist.at(i);
-		wxString spid;
-		bool selfPid = (entry.pid == (long)wxGetProcessId());
-		spid << entry.pid;
-		SetColumnText(m_listCtrlProcesses, item, 0, spid);
-		SetColumnText(m_listCtrlProcesses, item, 1, entry.name);
-		
-		if(selfPid) {
-			m_listCtrlProcesses->SetItemTextColour(item, wxSystemSettings::GetColour(wxSYS_COLOUR_GRAYTEXT));
+
+		// Use case in-sensitive match for the filter
+		wxString entryName (proclist.at(i).name);
+		entryName.MakeLower();
+
+		// Append only processes that matches the filter string
+		if ( filter.IsEmpty() || entryName.Contains(filter) ) {
+			long item = AppendListCtrlRow(m_listCtrlProcesses);
+			ProcessEntry entry = proclist.at(i);
+			wxString spid;
+			bool selfPid = (entry.pid == (long)wxGetProcessId());
+			spid << entry.pid;
+			SetColumnText(m_listCtrlProcesses, item, 0, spid);
+			SetColumnText(m_listCtrlProcesses, item, 1, entry.name);
+
+			if (selfPid) {
+				m_listCtrlProcesses->SetItemTextColour(item, wxSystemSettings::GetColour(wxSYS_COLOUR_GRAYTEXT));
+			}
 		}
+
 	}
-	
+
 	m_listCtrlProcesses->SetColumnWidth(0, 100);
-	m_listCtrlProcesses->SetColumnWidth(1, 200);
+	m_listCtrlProcesses->SetColumnWidth(1, 500);
 	m_listCtrlProcesses->Thaw();
 }
 
@@ -118,7 +130,7 @@ wxString AttachDbgProcDlg::GetProcessId() const
 
 void AttachDbgProcDlg::OnSortColumn( wxListEvent& event )
 {
-	RefreshProcessesList( event.m_col );
+	RefreshProcessesList( m_textCtrlFilter->GetValue(), event.m_col );
 }
 
 void AttachDbgProcDlg::OnItemActivated( wxListEvent& event )
@@ -148,3 +160,18 @@ AttachDbgProcDlg::~AttachDbgProcDlg()
 {
 	WindowAttrManager::Save(this, wxT("AttachDbgProcDlg"), NULL);
 }
+
+void AttachDbgProcDlg::OnFilter(wxCommandEvent& event)
+{
+	wxUnusedVar(event);
+	RefreshProcessesList(m_textCtrlFilter->GetValue());
+}
+
+void AttachDbgProcDlg::OnRefresh(wxCommandEvent& event)
+{
+	wxUnusedVar(event);
+	// Clear all filters and refresh the processes list
+	m_textCtrlFilter->Clear();
+	RefreshProcessesList(wxEmptyString);
+	m_textCtrlFilter->SetFocus();
+}
