@@ -43,19 +43,20 @@ DEFINE_EVENT_TYPE(wxEVT_FRD_CLEARBOOKMARKS)
 BEGIN_EVENT_TABLE(FindReplaceDialog, wxDialog)
 	EVT_CLOSE(FindReplaceDialog::OnClose)
 	EVT_CHAR_HOOK(FindReplaceDialog::OnKeyDown)
+	EVT_COMMAND(wxID_ANY, wxEVT_FRD_FIND_NEXT, FindReplaceDialog::OnFindEvent)
 END_EVENT_TABLE()
 
 #define VALIDATE_FINDWHAT(){\
-	if(m_findString->GetValue().IsEmpty()){\
+		if(m_findString->GetValue().IsEmpty()){\
 			wxMessageBox(_("'Find What' is empty"));\
 			return;\
 		}\
-}
+	}
 
 FindReplaceDialog::FindReplaceDialog()
-		: wxDialog()
-		, m_owner(NULL)
-		, m_kind(FIND_DLG)
+	: wxDialog()
+	, m_owner(NULL)
+	, m_kind(FIND_DLG)
 {
 }
 
@@ -111,20 +112,22 @@ void FindReplaceDialog::CreateGUIControls()
 
 	wxStaticText* itemStaticText;
 	itemStaticText = new wxStaticText( this, wxID_STATIC, wxT("Find What:"), wxDefaultPosition, wxDefaultSize, wxALIGN_LEFT );
-	gbSizer->Add(itemStaticText, wxGBPosition(0, 0), wxDefaultSpan, wxALL | wxEXPAND, 5 );
+	gbSizer->Add(itemStaticText, wxGBPosition(0, 0), wxDefaultSpan, wxALL, 5 );
 
 	m_findString = new wxComboBox( this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxSize(200, -1));
 	gbSizer->Add(m_findString, wxGBPosition(0, 1), wxDefaultSpan, wxALL | wxEXPAND, 5 );
 
 	m_replaceWithLabel = new wxStaticText( this, wxID_STATIC, wxT("Replace With:"), wxDefaultPosition, wxDefaultSize, wxALIGN_LEFT );
-	gbSizer->Add(m_replaceWithLabel, wxGBPosition(1, 0), wxDefaultSpan, wxALL | wxEXPAND, 5 );
+	gbSizer->Add(m_replaceWithLabel, wxGBPosition(1, 0), wxDefaultSpan, wxALL, 5 );
 
-	m_replaceString = new wxComboBox(this, wxID_ANY, wxEmptyString, wxDefaultPosition);
+	m_replaceString = new wxComboBox(this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxSize(200, -1));
 	gbSizer->Add(m_replaceString, wxGBPosition(1, 1), wxDefaultSpan, wxALL | wxEXPAND, 5 );
 
 	sz = new wxStaticBoxSizer(wxVERTICAL, this, wxT("Options"));
 	gbSizer->Add(sz, wxGBPosition(2, 0), wxGBSpan(1, 2),  wxALL | wxEXPAND, 5 );
 
+	gbSizer->AddGrowableCol(1);
+
 	m_matchCase = new wxCheckBox(this, wxID_ANY, wxT("&Match case"));
 	sz->Add(m_matchCase, 1, wxALL | wxEXPAND, 5 );
 
@@ -169,6 +172,11 @@ void FindReplaceDialog::CreateGUIControls()
 	SetFindReplaceData(m_data, true);
 }
 
+void FindReplaceDialog::OnFindEvent(wxCommandEvent &event)
+{
+	SetFindReplaceData(GetData(), false);
+}
+
 void FindReplaceDialog::SetFindReplaceData(FindReplaceData &data, bool focus)
 {
 	m_findString->Freeze();
@@ -276,7 +284,14 @@ void FindReplaceDialog::OnClick(wxCommandEvent &event)
 
 	// update the data of the find/replace dialog, in particular,
 	// update the history of the Find What / replace with controls
+#if defined(__WXGTK__) && wxVERSION_NUMBER >= 2900
+	// But if it's a findNext or a Replace, do it by posting an event,
+	// otherwise strange duplications happen (because scintilla steals the primary selection?)
+	wxCommandEvent e(wxEVT_FRD_FIND_NEXT); // Arbitrary choice of event-type
+	wxPostEvent(this, e);
+#else
 	SetFindReplaceData(m_data, false);
+#endif
 }
 
 void FindReplaceDialog::OnClose(wxCloseEvent &event)
@@ -286,7 +301,13 @@ void FindReplaceDialog::OnClose(wxCloseEvent &event)
 	// Fire a close event
 	SendEvent(wxEVT_FRD_CLOSE);
 	Hide();
+
+	// Make sure the Search in Selected Text flag is clear, otherwise we can't Find Next
+	size_t flags = m_data.GetFlags();
+	flags &= ~(wxFRD_SELECTIONONLY);
+	m_data.SetFlags( flags );
 }
+
 void FindReplaceDialog::OnKeyDown(wxKeyEvent &event)
 {
 	if (event.GetKeyCode() == WXK_RETURN || event.GetKeyCode() == WXK_NUMPAD_ENTER) {
@@ -305,9 +326,9 @@ void FindReplaceDialog::OnKeyDown(wxKeyEvent &event)
 		//hide the find/replace dialog
 		if (IsShown()) {
 			Hide();
-		// Make sure the Search in Selected Text flag is clear, otherwise we can't Find Next
+			// Make sure the Search in Selected Text flag is clear, otherwise we can't Find Next
 			ResetSelectionOnlyFlag();
-		// For similar reasons, ensure the Find and Replace buttons are enabled
+			// For similar reasons, ensure the Find and Replace buttons are enabled
 			m_find->Enable(true);
 			m_replace->Enable(true);
 			event.Skip(false);
@@ -333,6 +354,8 @@ void FindReplaceDialog::ConnectEvents()
 	m_regualrExpression->Connect(wxID_ANY, wxEVT_COMMAND_CHECKBOX_CLICKED , wxCommandEventHandler(FindReplaceDialog::OnClick), NULL, this);
 	m_searchUp->Connect(wxID_ANY, wxEVT_COMMAND_CHECKBOX_CLICKED , wxCommandEventHandler(FindReplaceDialog::OnClick), NULL, this);
 	m_selectionOnly->Connect(wxID_ANY, wxEVT_COMMAND_CHECKBOX_CLICKED , wxCommandEventHandler(FindReplaceDialog::OnClick), NULL, this);
+	m_find->Connect(wxID_ANY, wxEVT_UPDATE_UI, wxUpdateUIEventHandler(FindReplaceDialog::OnSelectionOnlyUI), NULL, this);
+	m_replace->Connect(wxID_ANY, wxEVT_UPDATE_UI, wxUpdateUIEventHandler(FindReplaceDialog::OnSelectionOnlyUI), NULL, this);
 }
 
 void FindReplaceDialog::SendEvent(wxEventType type)
@@ -340,9 +363,9 @@ void FindReplaceDialog::SendEvent(wxEventType type)
 	wxCommandEvent event(type, GetId());
 	event.SetEventObject(this);
 
-	if ( GetEventOwner() == NULL ){
+	if ( GetEventOwner() == NULL ) {
 		GetEventHandler()->ProcessEvent( event );
-	}else{
+	} else {
 		// If an event owner was provided, pass it the event
 		GetEventOwner()->ProcessEvent( event );
 	}
@@ -361,7 +384,7 @@ bool FindReplaceDialog::Show(int kind)
 
 	if(kind == FIND_DLG) {
 		ShowReplaceControls(false);
-	}else{
+	} else {
 		ShowReplaceControls(true);
 	}
 
@@ -435,6 +458,11 @@ void FindReplaceDialog::ResetSelectionOnlyFlag()
 	GetData().SetFlags( flags & ~(wxFRD_SELECTIONONLY) );
 }
 
+void FindReplaceDialog::OnSelectionOnlyUI(wxUpdateUIEvent& event)
+{
+	event.Enable(m_selectionOnly->IsChecked() == false);
+}
+
 //---------------------------------------------------------------
 // FindReplaceData
 //---------------------------------------------------------------
@@ -448,40 +476,10 @@ void FindReplaceData::SetReplaceString(const wxString& str)
 	}
 	m_replaceString.Insert(str, 0);
 
-	long max_value(10);
-	EditorConfigST::Get()->GetLongValue(wxT("MaxItemsInFindReplaceDialog"), max_value);
+	long max_value = clConfig::Get().Read("MaxItemsInFindReplaceDialog", 15);
 	TruncateArray(m_replaceString, (size_t)max_value);
 }
 
-void FindReplaceData::Serialize(Archive& arch)
-{
-	arch.Write(wxT("m_findString"),    m_findString);
-	arch.Write(wxT("m_replaceString"), m_replaceString);
-	arch.Write(wxT("m_flags"),         (long)m_flags);
-	arch.Write(wxT("m_searchPaths"),   m_searchPaths);
-	arch.Write(wxT("m_encoding"),      m_encoding);
-	arch.Write(wxT("m_fileMask"),      m_fileMask);
-	arch.Write(wxT("m_selectedMask"),  m_selectedMask);
-}
-
-void FindReplaceData::DeSerialize(Archive& arch)
-{
-	arch.Read(wxT("m_findString"),    m_findString);
-	arch.Read(wxT("m_replaceString"), m_replaceString);
-	arch.Read(wxT("m_flags"),         (long&)m_flags);
-	arch.Read(wxT("m_searchPaths"),   m_searchPaths);
-	arch.Read(wxT("m_encoding"),      m_encoding);
-	arch.Read(wxT("m_fileMask"),      m_fileMask);
-	arch.Read(wxT("m_selectedMask"),  m_selectedMask);
-
-	long max_value(10);
-	EditorConfigST::Get()->GetLongValue(wxT("MaxItemsInFindReplaceDialog"), max_value);
-
-	TruncateArray(m_findString,    (size_t)max_value);
-	TruncateArray(m_replaceString, (size_t)max_value);
-	TruncateArray(m_searchPaths,   (size_t)max_value);
-}
-
 void FindReplaceData::SetFindString(const wxString& str)
 {
 	int where = m_findString.Index(str);
@@ -490,8 +488,7 @@ void FindReplaceData::SetFindString(const wxString& str)
 	}
 	m_findString.Insert(str, 0);
 
-	long max_value(10);
-	EditorConfigST::Get()->GetLongValue(wxT("MaxItemsInFindReplaceDialog"), max_value);
+	long max_value = clConfig::Get().Read("MaxItemsInFindReplaceDialog", 15);
 	TruncateArray(m_findString, (size_t)max_value);
 }
 
@@ -508,6 +505,7 @@ wxString FindReplaceData::GetFindString() const
 {
 	if (m_findString.IsEmpty()) {
 		return wxEmptyString;
+
 	} else {
 		return m_findString.Item(0);
 	}
@@ -519,3 +517,70 @@ void FindReplaceData::TruncateArray(wxArrayString& arr, size_t maxSize)
 		arr.RemoveAt(arr.GetCount()-1);
 	}
 }
+void FindReplaceData::FromJSON(const JSONElement& json)
+{
+	m_findString    = json.namedObject("m_findString").toArrayString();
+	m_replaceString = json.namedObject("m_replaceString").toArrayString();
+	m_searchScope   = json.namedObject("m_searchScope").toInt(m_searchScope);
+	m_flags         = json.namedObject("m_flags").toSize_t(m_flags);
+	m_searchPaths   = json.namedObject("m_searchPaths").toArrayString();
+	m_encoding      = json.namedObject("m_encoding").toString(m_encoding);
+	m_fileMask      = json.namedObject("m_fileMask").toArrayString();
+	m_selectedMask  = json.namedObject("m_selectedMask").toString(m_selectedMask);
+
+	long max_value = clConfig::Get().Read("MaxItemsInFindReplaceDialog", 15);
+
+	TruncateArray(m_searchPaths,   (size_t)max_value);
+	TruncateArray(m_replaceString, (size_t)max_value);
+	TruncateArray(m_findString,    (size_t)max_value);
+
+	if ( m_fileMask.IsEmpty() ) {
+		m_fileMask.Add("*.c;*.cpp;*.cxx;*.cc;*.h;*.hpp;*.inc;*.mm;*.m;*.xrc");
+		m_selectedMask =  "*.c;*.cpp;*.cxx;*.cc;*.h;*.hpp;*.inc;*.mm;*.m;*.xrc";
+	}
+}
+
+JSONElement FindReplaceData::ToJSON() const
+{
+	JSONElement element = JSONElement::createObject(GetName());
+	element.addProperty("m_findString",    m_findString);
+	element.addProperty("m_replaceString", m_replaceString);
+	element.addProperty("m_searchScope",   m_searchScope);
+	element.addProperty("m_flags",         m_flags);
+	element.addProperty("m_searchPaths",   m_searchPaths);
+	element.addProperty("m_encoding",      m_encoding);
+	element.addProperty("m_fileMask",      m_fileMask);
+	element.addProperty("m_selectedMask",  m_selectedMask);
+	return element;
+}
+
+wxArrayString FindReplaceData::GetFindStringArr() const
+{
+	wxArrayString findArr;
+	for(size_t i=0; i<m_findString.GetCount(); ++i) {
+		if ( (findArr.Index(m_findString.Item(i)) == wxNOT_FOUND) && !m_findString.Item(i).IsEmpty() ) {
+			findArr.Add( m_findString.Item(i) );
+		}
+	}
+	return findArr;
+}
+
+wxArrayString FindReplaceData::GetReplaceStringArr() const
+{
+	wxArrayString replaceArr;
+	for(size_t i=0; i<m_replaceString.GetCount(); ++i) {
+		if ( (replaceArr.Index(m_replaceString.Item(i)) == wxNOT_FOUND) && !m_replaceString.Item(i).IsEmpty() ) {
+			replaceArr.Add( m_replaceString.Item(i) );
+		}
+	}
+	return replaceArr;
+}
+
+FindReplaceData::FindReplaceData()
+	: clConfigItem("FindReplaceData")
+	, m_flags(0)
+	, m_searchScope(1)
+	, m_selectedMask("*.c;*.cpp;*.cxx;*.cc;*.h;*.hpp;*.inc;*.mm;*.m;*.xrc") // Default file mask
+{
+	m_fileMask.Add("*.c;*.cpp;*.cxx;*.cc;*.h;*.hpp;*.inc;*.mm;*.m;*.xrc");
+}
