@@ -28,15 +28,19 @@
 #include <wx/panel.h>
 
 #include "shelltab.h"
+#include "cl_command_event.h"
 
 class FindResultsTab;
+#if CL_USE_NEW_BUILD_TAB
+class NewBuildTab;
+#else
 class BuildTab;
-class ErrorsTab;
+#endif
 class ReplaceInFilesPanel;
 class ShellTab;
-class DebugTab;
 class TaskPanel;
 class OutputPaneBook;
+class FindUsageTab;
 
 /**
  * \ingroup LiteEditor
@@ -57,52 +61,61 @@ class OutputPaneBook;
 class OutputPane : public wxPanel
 {
 public:
-	static const wxString FIND_IN_FILES_WIN;
-	static const wxString BUILD_WIN;
-	static const wxString ERRORS_WIN;
-	static const wxString OUTPUT_WIN;
-	static const wxString OUTPUT_DEBUG;
-	static const wxString REPLACE_IN_FILES;
-	static const wxString TASKS;
-	static const wxString TRACE_TAB;
+    static const wxString FIND_IN_FILES_WIN;
+    static const wxString BUILD_WIN;
+    static const wxString OUTPUT_WIN;
+    static const wxString OUTPUT_DEBUG;
+    static const wxString REPLACE_IN_FILES;
+    static const wxString TASKS;
+    static const wxString TRACE_TAB;
+    static const wxString SHOW_USAGE;
 
 private:
-	wxString m_caption;
-	wxLog   *m_logTargetOld;
+    wxString m_caption;
+    wxLog* m_logTargetOld;
 
-	OutputPaneBook        *m_book;
-	FindResultsTab        *m_findResultsTab;
-	ReplaceInFilesPanel   *m_replaceResultsTab;
-	BuildTab              *m_buildWin;
-	ErrorsTab             *m_errorsWin;
-	ShellTab              *m_outputWind;
-	DebugTab              *m_outputDebug;
-	TaskPanel             *m_taskPanel;
+    Notebook* m_book;
+    FindResultsTab* m_findResultsTab;
+    ReplaceInFilesPanel* m_replaceResultsTab;
 
-	void CreateGUIControls();
+#if CL_USE_NEW_BUILD_TAB
+    NewBuildTab* m_buildWin;
+#else
+    BuildTab* m_buildWin;
+#endif
+
+    ShellTab* m_outputWind;
+    TaskPanel* m_taskPanel;
+    FindUsageTab* m_showUsageTab;
+    bool m_buildInProgress;
+
+protected:
+    void CreateGUIControls();
+    void OnEditorFocus(wxCommandEvent& e);
+    void OnBuildStarted(clBuildEvent& e);
+    void OnBuildEnded(clBuildEvent& e);
 
 public:
-	/**
-	 * Constructor
-	 * \param parent parent window for this pane
-	 * \param caption the caption
-	 */
-	OutputPane(wxWindow *parent, const wxString &caption);
+    /**
+     * Constructor
+     * \param parent parent window for this pane
+     * \param caption the caption
+     */
+    OutputPane(wxWindow* parent, const wxString& caption);
 
-	/**
-	 * Destructor
-	 */
-	virtual ~OutputPane();
+    /**
+     * Destructor
+     */
+    virtual ~OutputPane();
 
-	OutputPaneBook       *GetNotebook()      { return m_book;    }
-	const wxString &     GetCaption () const { return m_caption; }
+    Notebook* GetNotebook() { return m_book; }
+    const wxString& GetCaption() const { return m_caption; }
 
-	FindResultsTab        *GetFindResultsTab   () { return m_findResultsTab;    }
-	ReplaceInFilesPanel   *GetReplaceResultsTab() { return m_replaceResultsTab; }
-	BuildTab              *GetBuildTab         () { return m_buildWin;          }
-	ErrorsTab             *GetErrorsTab        () { return m_errorsWin;         }
-	ShellTab              *GetOutputWindow     () { return m_outputWind;        }
-	DebugTab              *GetDebugWindow      () { return m_outputDebug;       }
+    FindResultsTab* GetFindResultsTab() { return m_findResultsTab; }
+    ReplaceInFilesPanel* GetReplaceResultsTab() { return m_replaceResultsTab; }
+    NewBuildTab* GetBuildTab() { return m_buildWin; }
+    ShellTab* GetOutputWindow() { return m_outputWind; }
+    FindUsageTab* GetShowUsageTab() { return m_showUsageTab; }
 };
 
 #endif // OUTPUT_PANE_H
