@@ -25,6 +25,7 @@
 #include <wx/xrc/xmlres.h>
 #include "editor_config.h"
 #include "taskspaneldata.h"
+#include <wx/fontmap.h>
 #include "tasks_find_what_dlg.h"
 #include <wx/tglbtn.h>
 #include "frame.h"
@@ -33,65 +34,91 @@
 #include "taskpanel.h"
 
 BEGIN_EVENT_TABLE(TaskPanel, FindResultsTab)
-    EVT_BUTTON(XRCID("search"),       TaskPanel::OnSearch)
-	EVT_BUTTON(XRCID("find_what"),    TaskPanel::OnFindWhat)
-    EVT_UPDATE_UI(XRCID("search"),    TaskPanel::OnSearchUI)
+    EVT_BUTTON    (wxID_FIND,               TaskPanel::OnSearch)
+	EVT_BUTTON    (XRCID("find_what"),      TaskPanel::OnFindWhat)
+    EVT_UPDATE_UI (wxID_FIND,               TaskPanel::OnSearchUI)
+	EVT_UPDATE_UI (XRCID("hold_pane_open"), TaskPanel::OnHoldOpenUpdateUI)
 END_EVENT_TABLE()
 
 TaskPanel::TaskPanel(wxWindow* parent, wxWindowID id, const wxString &name)
     : FindResultsTab(parent, id, name)
     , m_scope(NULL)
-    , m_filter(NULL)
 {
     wxArrayString scopes;
-    scopes.Add(SEARCH_IN_PROJECT);
-    scopes.Add(SEARCH_IN_WORKSPACE);
-    scopes.Add(SEARCH_IN_CURR_FILE_PROJECT);
+    scopes.Add(wxGetTranslation(SEARCH_IN_PROJECT));
+    scopes.Add(wxGetTranslation(SEARCH_IN_WORKSPACE));
+    scopes.Add(wxGetTranslation(SEARCH_IN_CURR_FILE_PROJECT));
 
     wxArrayString filters;
-    filters.Add(wxT("C/C++ Sources"));
+    filters.Add( wxString(wxT("C/C++ ")) + _("Sources"));
     m_extensions.Add(wxT("*.c;*.cpp;*.cxx;*.cc;*.h;*.hpp;*.hxx;*.hh;*.inl;*.inc;*.hh"));
-    filters.Add(wxT("All Files"));
+    filters.Add(_("All Files"));
     m_extensions.Add(wxT("*.*"));
 
-    wxBoxSizer *horzSizer = new wxBoxSizer(wxHORIZONTAL);
-
-    wxStaticText *text = new wxStaticText(this, wxID_ANY, wxT("Search Tasks in:"));
-    horzSizer->Add(text, 0, wxRIGHT|wxLEFT|wxALIGN_CENTER_VERTICAL, 5);
-
+    wxBoxSizer *verticalPanelSizer = new wxBoxSizer(wxVERTICAL);
+	
+	wxButton *btn = new wxButton(this, wxID_FIND, _("&Search"));
+    verticalPanelSizer->Add(btn, 0, wxEXPAND|wxALL, 5);
+	
+	m_findWhat = new wxButton(this, XRCID("find_what"), _("Find What..."));
+	verticalPanelSizer->Add(m_findWhat, 0, wxEXPAND|wxALL, 5);
+	verticalPanelSizer->Add(new wxStaticLine(this), 0, wxEXPAND|wxALL, 5);
+	
     m_scope = new wxChoice(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, scopes);
     m_scope->SetSelection(0);
-    horzSizer->Add(m_scope, 1, wxRIGHT|wxLEFT|wxALIGN_CENTER_VERTICAL, 2);
+	m_scope->SetToolTip(_("Select the scope of the search"));
+    verticalPanelSizer->Add(m_scope, 0, wxEXPAND|wxALL, 5);
+    
+    m_choiceEncoding = new wxChoice(this, wxID_ANY);
+    verticalPanelSizer->Add(m_choiceEncoding, 0, wxEXPAND|wxALL, 5);
+    m_choiceEncoding->SetToolTip(_("Encoding to use for the search"));
+    
+    TasksPanelData d;
+	EditorConfigST::Get()->ReadObject(wxT("TasksPanelData"), &d);
+    
+    // Set encoding
+	wxArrayString  astrEncodings;
+	wxFontEncoding fontEnc;
+	int            selection(0);
 
-    m_filter = new wxChoice(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, filters);
-    m_filter->SetSelection(0);
-    horzSizer->Add(m_filter, 1, wxRIGHT|wxLEFT|wxALIGN_CENTER_VERTICAL, 2);
+	size_t iEncCnt = wxFontMapper::GetSupportedEncodingsCount();
+	for (size_t i = 0; i < iEncCnt; i++) {
+		fontEnc = wxFontMapper::GetEncoding(i);
+		if (wxFONTENCODING_SYSTEM == fontEnc) { // skip system, it is changed to UTF-8 in optionsconfig
+			continue;
+		}
+		wxString encodingName = wxFontMapper::GetEncodingName(fontEnc);
+		size_t pos = astrEncodings.Add(encodingName);
 
-    wxButton *btn = new wxButton(this, XRCID("search"), wxT("&Search"));
-    horzSizer->Add(btn, 0, wxRIGHT|wxLEFT|wxALIGN_CENTER_VERTICAL, 5);
-
-	m_findWhat = new wxButton(this, XRCID("find_what"), _("Find What..."));
-	horzSizer->Add(m_findWhat, 0, wxRIGHT|wxLEFT|wxALIGN_CENTER_VERTICAL, 2);
-
-	wxBoxSizer *vertSizer = new wxBoxSizer(wxVERTICAL);
-	vertSizer->Add(horzSizer, 0, wxEXPAND|wxTOP|wxBOTTOM);
+		if(d.GetEncoding() == encodingName)
+			selection = static_cast<int>(pos);
+	}
 
+	m_choiceEncoding->Append(astrEncodings);
+	if(m_choiceEncoding->IsEmpty() == false)
+		m_choiceEncoding->SetSelection(selection);
+        
+    m_choiceEncoding->Connect(wxEVT_COMMAND_CHOICE_SELECTED, wxCommandEventHandler(TaskPanel::OnEncodingSelected), NULL, this);
+    
+	wxBoxSizer *hSizer = new wxBoxSizer(wxHORIZONTAL);
+	
 	// grab the base class scintilla and put our sizer in its place
-	wxSizer *mainSizer = GetSizer();
+	wxSizer *mainSizer = m_hSizer;
 	mainSizer->Detach(m_sci);
-	vertSizer->Add(m_sci, 1, wxEXPAND | wxALL, 1);
-
+	hSizer->Add(m_sci, 1, wxEXPAND | wxALL, 1);
+	hSizer->Add(verticalPanelSizer, 0, wxEXPAND|wxALL, 1);
+	
 #ifdef __WXMAC__
-	mainSizer->Insert(0, vertSizer, 1, wxEXPAND | wxALL, 1);
+	mainSizer->Insert(0, hSizer, 1, wxEXPAND | wxALL, 1);
 #else
-	mainSizer->Add(vertSizer, 1, wxEXPAND | wxALL, 1);
+	mainSizer->Add(hSizer, 1, wxEXPAND | wxALL, 1);
 #endif
-
 	mainSizer->Layout();
 }
 
 TaskPanel::~TaskPanel()
 {
+    m_choiceEncoding->Disconnect(wxEVT_COMMAND_CHOICE_SELECTED, wxCommandEventHandler(TaskPanel::OnEncodingSelected), NULL, this);
 }
 
 SearchData TaskPanel::DoGetSearchData()
@@ -101,7 +128,7 @@ SearchData TaskPanel::DoGetSearchData()
     data.SetRegularExpression(true);
     data.SetMatchCase(false);
     data.SetMatchWholeWord(false);
-    data.SetEncoding(wxT("ISO-8859-1"));
+    data.SetEncoding(m_choiceEncoding->GetStringSelection());
     data.SetOwner(this);
 
 	wxString sfind;
@@ -131,21 +158,20 @@ SearchData TaskPanel::DoGetSearchData()
 	wxArrayString rootDirs;
 	rootDirs.push_back(rootDir);
     data.SetRootDirs(rootDirs);
+	
     wxArrayString files;
-	if (rootDir == SEARCH_IN_WORKSPACE) {
+	if (rootDir == wxGetTranslation(SEARCH_IN_WORKSPACE)) {
 		ManagerST::Get()->GetWorkspaceFiles(files);
-	} else if (rootDir == SEARCH_IN_PROJECT) {
-		ManagerST::Get()->GetProjectFiles(ManagerST::Get()->GetActiveProjectName(), files);
-	} else if (rootDir == SEARCH_IN_CURR_FILE_PROJECT) {
-		wxString project = ManagerST::Get()->GetActiveProjectName();
-		if (Frame::Get()->GetMainBook()->GetActiveEditor()) {
-			wxFileName activeFile = Frame::Get()->GetMainBook()->GetActiveEditor()->GetFileName();
-			project = ManagerST::Get()->GetProjectNameByFile(activeFile.GetFullPath());
-		}
-		ManagerST::Get()->GetProjectFiles(project, files);
+		
+	} else if (rootDir == wxGetTranslation(SEARCH_IN_PROJECT)) {
+		ManagerST::Get()->GetActiveProjectFiles(files);
+		
+	} else if (rootDir == wxGetTranslation(SEARCH_IN_CURR_FILE_PROJECT)) {
+		ManagerST::Get()->GetActiveFileProjectFiles(files);
+		
 	}
     data.SetFiles(files);
-    data.SetExtensions(m_extensions[m_filter->GetSelection()]);
+    data.SetExtensions(wxT("*.*"));
 
 	return data;
 }
@@ -169,6 +195,35 @@ void TaskPanel::OnRepeatOutput(wxCommandEvent& e)
 
 void TaskPanel::OnFindWhat(wxCommandEvent& e)
 {
-	TasksFindWhatDlg dlg(this);
+	TasksFindWhatDlg dlg(wxTheApp->GetTopWindow());
 	dlg.ShowModal();
 }
+
+void TaskPanel::OnHoldOpenUpdateUI(wxUpdateUIEvent& e)
+{
+	int sel = clMainFrame::Get()->GetOutputPane()->GetNotebook()->GetSelection();
+	if (clMainFrame::Get()->GetOutputPane()->GetNotebook()->GetPage(sel) != this) {
+		return;
+	}
+
+	if(EditorConfigST::Get()->GetOptions()->GetHideOutpuPaneOnUserClick()) {
+		e.Enable(true);
+		e.Check( EditorConfigST::Get()->GetOptions()->GetHideOutputPaneNotIfTasks() );
+		
+	} else {
+		e.Enable(false);
+		e.Check(false);
+	}
+}
+
+void TaskPanel::OnEncodingSelected(wxCommandEvent& e)
+{
+    wxUnusedVar(e);
+    
+    TasksPanelData d;
+	EditorConfigST::Get()->ReadObject(wxT("TasksPanelData"), &d);
+    
+    d.SetEncoding(m_choiceEncoding->GetStringSelection());
+    EditorConfigST::Get()->WriteObject(wxT("TasksPanelData"), &d);
+}
+
