@@ -35,19 +35,18 @@ class TaskPanel : public FindResultsTab
 {
 private:
     wxArrayString m_extensions;
-	std::vector<wxToggleButton*> m_task;
+	wxButton *m_findWhat;
     wxChoice *m_scope;
-    wxChoice *m_filter;
-
+    wxChoice *m_choiceEncoding;
+    
 protected:
-    SearchData DoGetSearchData();
-    void       OnToggle       (wxCommandEvent  &e);
-	void       OnSearch       (wxCommandEvent  &e);
-    void       OnCustomize    (wxCommandEvent  &e);
-    void       OnSearchUI     (wxUpdateUIEvent &e);
-    void       OnCustomizeUI  (wxUpdateUIEvent &e);
-	void       OnRepeatOutput (wxCommandEvent  &e);
-
+    SearchData DoGetSearchData   ();
+    void       OnFindWhat        (wxCommandEvent  &e);
+	void       OnSearch          (wxCommandEvent  &e);
+    void       OnSearchUI        (wxUpdateUIEvent &e);
+	void       OnRepeatOutput    (wxCommandEvent  &e);
+	void       OnHoldOpenUpdateUI(wxUpdateUIEvent& e);
+	void       OnEncodingSelected(wxCommandEvent& e);
     DECLARE_EVENT_TABLE()
 
 public:
