@@ -1,3 +1,28 @@
+//////////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+//
+// copyright            : (C) 2014 The CodeLite Team
+// file name            : macbundler.cpp
+//
+// -------------------------------------------------------------------------
+// A
+//              _____           _      _     _ _
+//             /  __ \         | |    | |   (_) |
+//             | /  \/ ___   __| | ___| |    _| |_ ___
+//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
+//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
+//              \____/\___/ \__,_|\___\_____/_|\__\___|
+//
+//                                                  F i l e
+//
+//    This program is free software; you can redistribute it and/or modify
+//    it under the terms of the GNU General Public License as published by
+//    the Free Software Foundation; either version 2 of the License, or
+//    (at your option) any later version.
+//
+//////////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+
 #include "macbundler.h"
 #include "wx/xrc/xmlres.h"
 #include "wx/textfile.h"
@@ -49,7 +74,7 @@ public:
         }
         else
         {
-            wxMessageBox(wxT("Failed to load image"));
+            wxMessageBox(_("Failed to load image"));
         }
     }
 
@@ -310,7 +335,7 @@ extern "C" EXPORT int GetPluginInterfaceVersion()
 MacBundler::MacBundler(IManager *manager)
 		: IPlugin(manager)
 {
-	m_longName = wxT("Manage OS X app bundles");
+	m_longName = _("Manage OS X app bundles");
 	m_shortName = wxT("MacBundler");
 }
 
@@ -645,18 +670,7 @@ void MacBundler::HookPopupMenu(wxMenu *menu, MenuType type)
 	}
 }
 
-void MacBundler::UnHookPopupMenu(wxMenu *menu, MenuType type)
-{
-	if (type == MenuTypeFileView_Project) {
-		wxMenuItem *item = menu->FindItem(XRCID("MACBUNDLER_PROJECT_MENU"));
-		if (item) {
-			menu->Destroy(item);
-		}
-	}
-}
-
 void MacBundler::UnPlug()
 {
-	//TODO:: perform the unplug action for this plugin
 }
 
