@@ -26,8 +26,9 @@
 #define COMPILE_REQUEST_H
 
 #include "shell_command.h"
+#include "codelite_exports.h"
 
-class CompileRequest : public ShellCommand {
+class WXDLLIMPEXP_SDK CompileRequest : public ShellCommand {
 	wxString m_fileName;
 	bool     m_premakeOnly;
     bool     m_preprocessOnly;
@@ -39,7 +40,7 @@ public:
 	 * \param projectName the selected project to build
 	 * \param configurationName the workspace selected configuration
 	 */
-	CompileRequest(	wxEvtHandler *owner, const QueueCommand &buildInfo,
+	CompileRequest( const QueueCommand &buildInfo,
 					const wxString &fileName = wxEmptyString,
 					bool runPremakeOnly = false,
                     bool preprocessOnly = false
