@@ -25,6 +25,8 @@
 #include "project_settings.h"
 #include "xmlutils.h"
 #include "project.h"
+#include "macros.h"
+#include "wx_xml_compatibility.h"
 
 ProjectSettings::ProjectSettings(wxXmlNode *node)
 {
@@ -100,11 +102,13 @@ BuildConfigPtr ProjectSettings::GetBuildConfiguration(const wxString &configName
 	BuildConfigPtr buildConfMerged(buildConf->Clone());
 	if (buildConfMerged->GetBuildCmpWithGlobalSettings() == BuildConfig::PREPEND_GLOBAL_SETTINGS) 	{
 		buildConfMerged->SetCompileOptions(buildConf->GetCompileOptions() + wxT(";") + m_globalSettings->GetCompileOptions());
+		buildConfMerged->SetCCompileOptions(buildConf->GetCCompileOptions() + wxT(";") + m_globalSettings->GetCCompileOptions());
 		buildConfMerged->SetPreprocessor(buildConf->GetPreprocessor() + wxT(";") + m_globalSettings->GetPreprocessor());
 		buildConfMerged->SetIncludePath(buildConf->GetIncludePath() + wxT(";") + m_globalSettings->GetIncludePath());
 	}
 	else if (buildConfMerged->GetBuildCmpWithGlobalSettings() == BuildConfig::APPEND_TO_GLOBAL_SETTINGS) {
 		buildConfMerged->SetCompileOptions(m_globalSettings->GetCompileOptions() + wxT(";") + buildConf->GetCompileOptions());
+		buildConfMerged->SetCCompileOptions(m_globalSettings->GetCCompileOptions() + wxT(";") + buildConf->GetCCompileOptions());
 		buildConfMerged->SetPreprocessor(m_globalSettings->GetPreprocessor() + wxT(";") + buildConf->GetPreprocessor());
 		buildConfMerged->SetIncludePath(m_globalSettings->GetIncludePath() + wxT(";") + buildConf->GetIncludePath());
 	}
@@ -152,6 +156,14 @@ BuildConfigPtr ProjectSettings::GetNextBuildConfiguration(ProjectSettingsCookie
 
 void ProjectSettings::SetBuildConfiguration(const BuildConfigPtr bc)
 {
+	if(!bc) return;
+	
+	// delete the old build configuration pointer if any
+	std::map<wxString, BuildConfigPtr>::iterator iter = m_configs.find(bc->GetName());
+	if(iter != m_configs.end())
+		m_configs.erase(iter);
+	
+	// replace with the new one
 	m_configs[bc->GetName()] = bc;
 }
 
