@@ -1,5 +1,31 @@
+//////////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+//
+// copyright            : (C) 2014 The CodeLite Team
+// file name            : qmakegenerator.cpp
+//
+// -------------------------------------------------------------------------
+// A
+//              _____           _      _     _ _
+//             /  __ \         | |    | |   (_) |
+//             | /  \/ ___   __| | ___| |    _| |_ ___
+//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
+//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
+//              \____/\___/ \__,_|\___\_____/_|\__\___|
+//
+//                                                  F i l e
+//
+//    This program is free software; you can redistribute it and/or modify
+//    it under the terms of the GNU General Public License as published by
+//    the Free Software Foundation; either version 2 of the License, or
+//    (at your option) any later version.
+//
+//////////////////////////////////////////////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+
 #include "qmakegenerator.h"
 #include "build_settings_config.h"
+#include "macromanager.h"
 #include "compiler.h"
 #include "wxmd5.h"
 #include "fileextmanager.h"
@@ -71,7 +97,10 @@ bool QMakeProFileGenerator::Generate()
 	pro_file << wxT("##########################################\n");
 	pro_file << wxT("# User section\n");
 	pro_file << wxT("##########################################\n");
-	pro_file << wxT("\n") << bcpd.m_freeText << wxT("\n");
+
+	// Expands any macros available in the user free text
+	wxString expandedText = MacroManager::Instance()->Expand(bcpd.m_freeText, m_manager, p->GetName(), m_configuration);
+	pro_file << wxT("\n") << expandedText << wxT("\n");
 
 	// incase we are building library, set the template back the lib
 	wxString type = p->GetSettings()->GetProjectType( bldConf->GetName() );
