@@ -83,7 +83,7 @@ extern "C" EXPORT PluginInfo GetPluginInfo()
 	PluginInfo info;
 	info.SetAuthor( wxT( "Frank Lichtner" ) );
 	info.SetName( plugName );
-	info.SetDescription( wxT( "A small tool to add expandable code snippets and template classes" ) );
+	info.SetDescription( _( "A small tool to add expandable code snippets and template classes" ) );
 	info.SetVersion( wxT( "v1.0" ) );
 	return info;
 }
@@ -146,7 +146,7 @@ SnipWiz::~SnipWiz()
 }
 //------------------------------------------------------------
 
-wxToolBar *SnipWiz::CreateToolBar( wxWindow *parent )
+clToolBar *SnipWiz::CreateToolBar( wxWindow *parent )
 {
 	return NULL;
 }
@@ -157,9 +157,9 @@ void SnipWiz::CreatePluginMenu( wxMenu *pluginsMenu )
 	wxMenu *menu = new wxMenu();
 	wxMenuItem *item( NULL );
 
-	item = new wxMenuItem( menu, IDM_SETTINGS, wxT( "Settings..." ), wxT( "Settings..." ), wxITEM_NORMAL );
+	item = new wxMenuItem( menu, IDM_SETTINGS, _( "Settings..." ), _( "Settings..." ), wxITEM_NORMAL );
 	menu->Append( item );
-	item = new wxMenuItem( menu, IDM_CLASS_WIZ, wxT( "Template class..." ), wxT( "Template class..." ), wxITEM_NORMAL );
+	item = new wxMenuItem( menu, IDM_CLASS_WIZ, _( "Template class..." ), _( "Template class..." ), wxITEM_NORMAL );
 	menu->Append( item );
 
 	pluginsMenu->Append( wxID_ANY, plugName, menu );
@@ -188,7 +188,7 @@ void SnipWiz::HookPopupMenu( wxMenu *menu, MenuType type )
 		menu->Prepend(item);
 		m_vdDynItems.push_back(item);
 
-		item = new wxMenuItem(menu, IDM_CLASS_WIZ, wxT("New Class from Template..."), wxEmptyString, wxITEM_NORMAL);
+		item = new wxMenuItem(menu, IDM_CLASS_WIZ, _("New Class from Template..."), wxEmptyString, wxITEM_NORMAL);
 		menu->Prepend(item);
 		m_vdDynItems.push_back(item);
 	}
@@ -196,24 +196,6 @@ void SnipWiz::HookPopupMenu( wxMenu *menu, MenuType type )
 
 //------------------------------------------------------------
 
-void SnipWiz::UnHookPopupMenu( wxMenu *menu, MenuType type )
-{
-	if ( type == MenuTypeEditor ) {
-		wxMenuItem *item = menu->FindItem( IDM_BASE );
-		if ( item ) {
-			menu->Destroy( item );
-		}
-	} else if (type == MenuTypeFileView_Folder) {
-		std::vector<wxMenuItem*>::iterator iter = m_vdDynItems.begin();
-		for (; iter != m_vdDynItems.end(); iter++) {
-			menu->Destroy(*iter);
-		}
-		m_vdDynItems.clear();
-	}
-}
-
-//------------------------------------------------------------
-
 void SnipWiz::UnPlug()
 {
 	m_topWin->Disconnect( IDM_SETTINGS, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( SnipWiz::OnSettings ), NULL, this );
@@ -236,10 +218,10 @@ void SnipWiz::OnMenuExpandSwitch( wxCommandEvent& e )
 	wxString var = editor->GetSelection();
 	if ( !var.IsEmpty() )
 		isSelection = true;
-	var = ::wxGetTextFromUser( wxT( "Enter identifier name" ), wxT( "switch(...)" ), var );
+	var = ::wxGetTextFromUser( _( "Enter identifier name" ), _( "switch(...)" ), var );
 	if ( var.IsEmpty() )
 		return;
-	long count = ::wxGetNumberFromUser( wxT( "Enter number of cases" ), wxT( "Cases:" ), wxT( "switch(...)" ), 1, 1, 20 );
+	long count = ::wxGetNumberFromUser( _( "Enter number of cases" ), _( "Cases:" ), _( "switch(...)" ), 1, 1, 20 );
 	if ( count < 1 )
 		return;
 
@@ -317,7 +299,11 @@ void SnipWiz::OnMenuSnippets( wxCommandEvent &e )
 			// format the text for insertion
 			wxString output = FormatOutput( editor, srText );
 
-			int curPos = editor->GetCurrentPosition() - selection.Len();
+			int curPos = editor->GetCurrentPosition();
+			if ( selection.Len() != 0 ) {
+				curPos = editor->GetSelectionStart();
+			}
+
 			// get caret position
 			long cursorPos = output.Find( REAL_CARET_STR );
 			if ( cursorPos != wxNOT_FOUND )
@@ -374,11 +360,11 @@ wxMenu* SnipWiz::CreateSubMenu()
 
 	wxMenuItem *item( NULL );
 	if ( !m_clipboard.IsEmpty() ) {
-		item = new wxMenuItem( parentMenu, IDM_PASTE, wxT( "Paste buffer" ), wxT( "Paste buffer" ), wxITEM_NORMAL );
+		item = new wxMenuItem( parentMenu, IDM_PASTE, _( "Paste buffer" ), _( "Paste buffer" ), wxITEM_NORMAL );
 		parentMenu->Append( item );
 		parentMenu->AppendSeparator();
 	}
-	item = new wxMenuItem( parentMenu, IDM_EXP_SWITCH, wxT( "switch{...}" ), wxT( "switch{...}" ), wxITEM_NORMAL );
+	item = new wxMenuItem( parentMenu, IDM_EXP_SWITCH, _( "switch{...}" ), _( "switch{...}" ), wxITEM_NORMAL );
 	parentMenu->Append( item );
 	parentMenu->AppendSeparator();
 
