@@ -47,7 +47,6 @@ public:
 	virtual clToolBar *CreateToolBar(wxWindow *parent);
 	virtual void CreatePluginMenu(wxMenu *pluginsMenu);
 	virtual void HookPopupMenu(wxMenu *menu, MenuType type);
-	virtual void UnHookPopupMenu(wxMenu *menu, MenuType type);
 	virtual void UnPlug();
 
 protected:
@@ -57,19 +56,23 @@ protected:
 	wxString GetCscopeExeName();
 	wxString DoCreateListFile(bool force);
 	void     DoCscopeCommand(const wxString &command, const wxString &findWhat, const wxString &endMsg);
+	void     DoFindSymbol(const wxString& word);
+	wxString GetSearchPattern() const;
 
 	//Event handlers
 	//------------------------------------------
-	void OnFindSymbol                      (wxCommandEvent &e);
-	void OnFindGlobalDefinition            (wxCommandEvent &e);
-	void OnFindFunctionsCalledByThisFuncion(wxCommandEvent &e);
-	void OnFindFunctionsCallingThisFunction(wxCommandEvent &e);
-	void OnCreateDB                        (wxCommandEvent &e);
-	void OnDoSettings                      (wxCommandEvent &e);
-	void OnCScopeThreadEnded               (wxCommandEvent &e);
-	void OnCScopeThreadUpdateStatus        (wxCommandEvent &e);
-	void OnCscopeUI                        (wxUpdateUIEvent &e);
-	void OnWorkspaceOpenUI                 (wxUpdateUIEvent &e);
+	void OnFindSymbol                       (wxCommandEvent &e);
+	void OnFindUserInsertedSymbol           (wxCommandEvent &e);
+	void OnFindGlobalDefinition             (wxCommandEvent &e);
+	void OnFindFunctionsCalledByThisFunction(wxCommandEvent &e);
+	void OnFindFunctionsCallingThisFunction (wxCommandEvent &e);
+	void OnFindFilesIncludingThisFname      (wxCommandEvent &e);
+	void OnCreateDB                         (wxCommandEvent &e);
+	void OnDoSettings                       (wxCommandEvent &e);
+	void OnCScopeThreadEnded                (wxCommandEvent &e);
+	void OnCScopeThreadUpdateStatus         (wxCommandEvent &e);
+	void OnCscopeUI                         (wxUpdateUIEvent &e);
+	void OnWorkspaceOpenUI                  (wxUpdateUIEvent &e);
 };
 
 #endif //Cscope
